@@ -1,3 +1,12 @@
+sd_section("Package overview", "",
+           c("ggpmisc-package")
+)
+
+sd_section("Plot creation",
+  "Additional ggplot methods",
+  c("ggplot")
+)
+
 sd_section("Geoms",
   "Geoms, short for geometric objects, describe the type of plot you will produce.",
   c(
